/*************************************************************************
*                           ADF4350x Tester
*                  Hardware Experimental Test Program
*                             
*                           
*************************************************************************/
/*  Source: https://github.com/darkbyte-ru/ADF4350
 *  Date: 2020-OCT-31 GJO
 *  V1.00 Inital working version
 * 
    ADF4350::initialize(int frequency, int refClk) 
             -- initializes PLL with given frequency (KHz) and 
             reference clock frequency (MHz).
    ADF4350::getFreq() -- returns current frequency
    ADF4350::setFreq(long freq) -- sets PLL to output new frequency freq (in KHz).

    Functions you should use after consulting datasheet:

    ADF4350::setFeedbackType(bool feedback) -- fundamental vs. divided feedback
    ADF4350::powerDown(bool pd) -- power down the VCO (or not).
    ADF4350::rfEnable(bool rf) -- enable/disable output on the main RF output.
    ADF4350::setRfPower(int pow) -- pow should be 0, 1, 2, or 3, corresponding 
             to -4, -1, 3, or 5 dBm.
    ADF4350::auxEnable(bool aux) -- enable/disable output on the auxilary output.
    ADF4350::setAuxPower(int pow) -- set auxiliary power output. 
             Again, pow should be 0, 1, 2, or 3, corresponding to -4, -1, 3, or 5 dBm.

*   Ver     Date        Who     Description
*   ---------------------------------------------------------------------
*   1.00    20.10.31    GJO     Initial test of ADF435x Eval Board
*                               - Fixed bug in ADF4350 Library caused by incorrect
*                               - register update register number order. 
*                               - Must be in descending R5-R0 order (See datasheet)
*  
*  
*  Library: Install ADF4350.h library using Arduino Library Manager
*  
*  ADF4351 PLL  Board Connections:
*  ===============================
*  2 VCC  - 5V
*  1 GND  - GND
*  6 SCK* - Connect to NANO-D13
*  7 DAT* - Connect to NANO-D11
*  8 LE*  - Connect to NANO-D8
*  5 MUXOUT - Free to use (Code uses it as LD output)
*  9 CE   - Connect to 3.3V 
*  
*  LD LED is enabled now, 0=Unlocked, 1=Locked
*  
*  10 GND
*  *) Use 820/1600 Ohm resistor divider to protect ADF4351 I/O voltage
*  
*  ADF435x EVAL BD NWDZ Connections
*  ================================================
*  
*  Coax Jack Center VCC  - 5V-9V
*  Coax Jack Sleeve GND
*  1 PDR  - Leave unconnected
*  7 GND  - GND
*  4 SCK* - Connect to NANO-D13
*  5 DAT* - Connect to NANO-D11
*  6 LE*  - Connect to NANO-D8
*  3 MUXOUT - Free to use (Code uses it as LD output)
*  8 CE   - Connect to 3.3V 
*  2 LD   - Is enabled now, 0=Unlocked, 1=Locked
*  10 GND
*  *) Use 820/1600 Ohm resistor divider to protect ADF4351 I/O voltage
*  
 */

#include <SPI.h>
#include <ADF4350.h> // Darkbyte.ru

#define PLL_REFERENCE_FREQ 10 //MHz clock 
#define PLL_LE_PIN 8

ADF4350 PLL(PLL_LE_PIN); // Create object PLL using D8 as LE pin

void setup()
{
  Serial.begin(9600);

  Serial.println("ADF4350 Startup OK");

  //init ADF4350 with 10MHz reference and tune to 144000
  PLL.initialize(144275, PLL_REFERENCE_FREQ);
  
  //default power is 0, which means -4dBm, 3 = 5dBm
  PLL.setRfPower(3);
  
//  PLL.rfEnable(0);

}

void loop()
{
/*
PLL.setFreq(425000);
delay(20);
PLL.setFreq(424000);
delay(20);
*/

}
